function [ obj, cpu_time, gap, node ] = reformulationComparison( file_name )

% Initialize outputs

obj = zeros( 6, 1 );
cpu_time = zeros( 6, 1);
gap = zeros( 6, 1 );
node = zeros( 6, 1 );

% Read data from file

[ Q, xi, u, alpha, beta, n, K, T, R ] = read_file( file_name );

% Improve alpha by lower bounding on  sum(x)=1, 0<=x<=u

for i = 1 : T
    [ X v ]  = linprog( xi( :, i ), [], [], ones( 1, n ), 1, zeros( n, 1 ), u );
    alpha( i ) = v;
end

% Improve beta by upper bounding on  sum(x)=1, 0<=x<=u

for i = 1 : T
    [ X v ]  = linprog( -xi( :, i ), [], [], ones( 1, n ), 1, zeros( n, 1 ), u );
    beta( i ) = -v;
end 

% Solve the standard formulation (MIQP_0)

[ obj( 1 ), cpu_time( 1 ), gap( 1 ), node( 1 ) ] = standardFormulation(  Q, u, xi, R, alpha, K, T, n );

% Solve the standard formulation with equality (MIQP_1)

[ obj( 2 ), cpu_time( 2 ), gap( 2 ), node( 2 ) ] = standardFormulationWithEquality(  Q, u, xi, R, alpha, K, T, n );

% Get the seta from SDP

[ seta, t_dsdp ] = setaFromSdp( n, K, Q, xi, R, alpha, beta, T, u );

% Solve Zheng Xiaojin's reformulation using the seta from SDP

[ obj( 3 ), cpu_time( 3 ), gap( 3 ), node( 3 ) ] =  RefCplex( Q, u, xi, R, alpha, beta, K, T, n, seta );

% Solve Zheng Xiaojin's reformulation with equality using the seta from SDP

[ obj( 4 ), cpu_time( 4 ), gap( 4 ), node( 4 ) ] = reformulationWithEquality( Q, u, xi, R, alpha, beta, K, T, n, seta );

% Get the new optimal seta from SDP

[ seta, t_dsdp ] = setaFromSdpNew( n, K, Q, xi, R, alpha, beta, T, u );

% Solve the new reformulation without socp constraints using the seta from SDP

[ obj( 5 ), cpu_time( 5 ), gap( 5 ), node( 5 ) ] = reformulationWithoutSocp( Q, u, xi, R, alpha, beta, K, T, n, seta );

% Get the seta from max eigenvalue

seta = setaFromMaxEigenvalue( Q, xi, T );

% Solve the new reformulation without socp constraints using the seta from max eigenvalue

[ obj( 6 ), cpu_time( 6 ), gap( 6 ), node( 6 ) ] = reformulationWithoutSocp( Q, u, xi, R, alpha, beta, K, T, n, seta );

end % End reformulationComparison

