function [ seta, t_dsdp ] = setaFromSdp( n, K, Q, xi, R, alpha, beta, T, u )
% setaFromSdp finds seta via DSDP_r as in Zheng Xiaojin' paper.

% Start the timer

tic

% Solve the SDP problem in cvx

E = ones( 1, n );

cvx_clear
cvx_begin sdp

    variables tau t rho(T) s z(T) seta(T) lamda(T) deta(T)
    variables mv(T) cigma(T)  zta(n) eta(n) vseta
    expression Q1

    maximize( tau + t + sum( rho ) )
    
    subject to % Constraints

    -t - K * s - sum( z ) >= 0;
    Q1 = Q - xi * diag( seta ) * xi';
    Q2 = zta - eta + E' * vseta;
    
    for i = 1 : T
        
        ei = xi( :, i );
        -z( i ) - s <= -seta( i ) * R^2 - lamda( i ) * R + deta( i );

        phi = 2 * seta( i ) + 2 * mv( i );
        ri = lamda( i ) - mv( i ) * ( alpha( i ) + R );
        cc = 2 * mv( i ) * alpha( i ) * R - 2 * deta( i );
        [ phi, ri; ri, cc ] >= 0;

        phi = 2 * seta( i ) + 2 * cigma( i );
        ri = lamda( i ) - cigma( i ) * ( beta( i ) + R );
        cc = 2 * cigma( i ) * beta( i ) * R - 2 * rho( i );
        [ phi, ri; ri, cc ] >= 0;

        Q2 = Q2 - lamda( i ) * ei;
        
    end % End for
    
    Q3 = -2 * zta' * u - 2 * vseta - 2 * tau;
    [ 2 * Q1, Q2; Q2', Q3 ] >= 0;
    z >= 0; 
    mv >= 0; 
    cigma >= 0;
    zta >= 0; 
    eta >= 0; 
    seta >= 0; % Additional condition seta>=0
    
cvx_end % End cvx


% Close the timer

toc

% Record the time for finding seta

t_dsdp = toc; 


end % End setaFromSdp

