function [ seta1, t_dsdp ] = setaFromSdpNew( n, K, Q, xi, R, alpha, beta, T, u )
% setaFromSdpNew finds the optimal seta for reformulationWithoutSocp.

% Start the timer

tic

% Solve the SDP problem in cvx

E = ones( 1, n );

cvx_clear
cvx_begin sdp

    variables tau rho( T ) s z( T ) seta1( T ) lamda( T ) deta( T ) myGamma( T ) mmu( T )
    variables nnu( T ) cigma( T ) zta( n ) eta( n ) vseta
    expression Q1
    
    maximize( tau - K * s - sum( z ) + sum( rho ) + sum( nnu ) - beta' * cigma + R * sum( deta ) )
    
    subject to
        %-t-K*s-sum(z) >= 0;
        Q1 = Q - xi * diag( seta1 ) * xi';
        Q2 = zta - eta + E' * vseta;

        for i = 1 : T
           ei = xi( :, i );
           - z( i ) - s <= - seta1( i ) * R^2 - lamda( i ) * R - myGamma( i ) * R + mmu( i ) * alpha( i );

           phi = 2 * seta1( i );
           ri = lamda( i ) + cigma( i ) - deta( i );
           cc = - 2 * rho( i );
           [ phi, ri; ri, cc ] >= 0;

           phi2 = 2 * seta1( i );
           ri2 = lamda( i ) + myGamma( i ) - mmu( i );
           cc2 = -2 * nnu( i );
           [ phi2, ri2; ri2, cc2 ] >= 0;

           Q2 = Q2 - lamda( i ) * ei;
        end % End for
        
        Q3 = - 2 * zta' * u - 2 * vseta - 2 * tau;
        [ 2 * Q1, Q2; Q2', Q3 ] >= 0;
        z >= 0;
        mmu >= 0;
        cigma >= 0;
        zta >= 0;
        eta >= 0;
        myGamma >= 0;
        deta >= 0;
        seta1 >= 0; % additional condition seta1>=0
cvx_end

% Close the timer

toc

% record time for finding seta1

t_dsdp = toc;

end % End setaFromSdpNew

